@@ -37,11 +37,11 @@
 
 // XXX Toolkit-specific preferences should be moved into toolkit.js
 
-//@line 41 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/browser/app/profile/firefox.js"
+//@line 41 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/browser/app/profile/firefox.js"
 
-//@line 44 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/browser/app/profile/firefox.js"
+//@line 44 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/browser/app/profile/firefox.js"
 
-//@line 50 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/browser/app/profile/firefox.js"
+//@line 50 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/browser/app/profile/firefox.js"
 
 pref("startup.homepage_override_url","chrome://browser-region/locale/region.properties");
 pref("general.startup.browser", true);
@@ -54,6 +54,8 @@ pref("xpinstall.dialog.progress.chrome", "chrome://mozapps/content/extensions/ex
 pref("xpinstall.dialog.progress.type.skin", "Extension:Manager-themes");
 pref("xpinstall.dialog.progress.type.chrome", "Extension:Manager-extensions");
 
+pref("extensions.getMoreExtensionsURL", "chrome://mozapps/locale/extensions/extensions.properties");
+pref("extensions.getMoreThemesURL", "chrome://mozapps/locale/extensions/extensions.properties");
 // Developers can set this to |true| if they are constantly changing files in their 
 // extensions directory so that the extension system does not constantly think that
 // their extensions are being updated and thus reregistered every time the app is
@@ -151,12 +153,12 @@ pref("keyword.URL", "http://www.google.com/search?btnI=I%27m+Feeling+Lucky&ie=UT
 
 pref("general.useragent.locale", "en-US");
 pref("general.skins.selectedSkin", "classic/1.0");
-pref("general.useragent.extra.firefox", "Firefox/1.5");
+pref("general.useragent.extra.firefox", "Firefox/1.5.0.2");
 
 pref("general.smoothScroll", false);
-//@line 163 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/browser/app/profile/firefox.js"
+//@line 165 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/browser/app/profile/firefox.js"
 pref("general.autoScroll", false);
-//@line 167 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/browser/app/profile/firefox.js"
+//@line 169 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/browser/app/profile/firefox.js"
 
 // Whether or not the application should check at startup each time if it 
 // is the default browser.
@@ -176,9 +178,9 @@ pref("browser.formfill.enable", true);
 
 pref("browser.download.useDownloadDir", true);
 pref("browser.download.folderList", 0);
-//@line 189 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/browser/app/profile/firefox.js"
+//@line 191 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/browser/app/profile/firefox.js"
 pref("browser.download.manager.showAlertOnComplete", false);
-//@line 191 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/browser/app/profile/firefox.js"
+//@line 193 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/browser/app/profile/firefox.js"
 pref("browser.download.manager.showAlertInterval", 2000);
 pref("browser.download.manager.retention", 2);
 pref("browser.download.manager.showWhenStarting", true);
@@ -304,12 +306,12 @@ pref("intl.menuitems.alwaysappendaccesskeys","chrome://global/locale/intl.proper
 pref("intl.menuitems.insertseparatorbeforeaccesskeys","chrome://global/locale/intl.properties");
 
 // 0=lines, 1=pages, 2=history , 3=text size
-//@line 325 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/browser/app/profile/firefox.js"
+//@line 327 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/browser/app/profile/firefox.js"
 pref("mousewheel.withcontrolkey.action",3);
 pref("mousewheel.withcontrolkey.sysnumlines",false);
 pref("mousewheel.withshiftkey.action",2);
 pref("mousewheel.withshiftkey.sysnumlines",false);
-//@line 330 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/browser/app/profile/firefox.js"
+//@line 332 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/browser/app/profile/firefox.js"
 pref("mousewheel.withaltkey.action",0);
 pref("mousewheel.withaltkey.sysnumlines",false);
 
@@ -359,9 +361,9 @@ pref("security.warn_leaving_secure.show_once", true);
 pref("security.warn_viewing_mixed.show_once", true);
 pref("security.warn_submit_insecure.show_once", true);
 
-//@line 380 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/browser/app/profile/firefox.js"
+//@line 382 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/browser/app/profile/firefox.js"
 pref("browser.urlbar.clickSelectsAll", false);
-//@line 384 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/browser/app/profile/firefox.js"
+//@line 386 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/browser/app/profile/firefox.js"
 
 pref("accessibility.typeaheadfind", false);
 pref("accessibility.typeaheadfind.timeout", 5000);
@@ -374,13 +376,13 @@ pref("plugin.default_plugin_disabled", true);
 // plugin finder service url
 pref("pfs.datasource.url", "https://pfs.mozilla.org/plugins/PluginFinderService.php?mimetype=%PLUGIN_MIMETYPE%&appID=%APP_ID%&appVersion=%APP_VERSION%&clientOS=%CLIENT_OS%&chromeLocale=%CHROME_LOCALE%");
 
-//@line 399 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/browser/app/profile/firefox.js"
+//@line 401 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/browser/app/profile/firefox.js"
 pref("browser.preferences.instantApply", true);
-//@line 404 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/browser/app/profile/firefox.js"
+//@line 406 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/browser/app/profile/firefox.js"
 pref("browser.preferences.animateFadeIn", false);
-//@line 407 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/browser/app/profile/firefox.js"
+//@line 409 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/browser/app/profile/firefox.js"
 pref("browser.display.screen_resolution", 96);
-//@line 409 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/browser/app/profile/firefox.js"
+//@line 411 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.EL_Depend/mozilla/browser/app/profile/firefox.js"
 
 pref("browser.download.show_plugins_in_list", true);
 pref("browser.download.hide_plugins_without_extensions", true);
